@@ -7,7 +7,8 @@ from pydantic import AnyHttpUrl, BaseSettings, validator
 class Settings(BaseSettings):
     PROJECT_NAME: str = 'OCPI'
     BACKEND_CORS_ORIGINS: List[AnyHttpUrl] = []
-    HOST: str = 'www.example.com'
+    OCPI_HOST: str = 'www.example.com'
+    OCPI_PREFIX: str = 'ocpi'
 
     @classmethod
     @validator("BACKEND_CORS_ORIGINS", pre=True)
